/**
 * 日志打印类.
 *
 * @author Y3G
 *
 * @fileoverview
 * Logger生成日志, Context打印日志.
 */
import { KonphGlobal } from "konph/src/types";
import { ChivyConfig } from "./config";
import { Level } from "./Filter";
declare type Styles = {
    level: (level: string) => string;
    module: (moduleName: string) => string;
    time: (now: string) => string;
    content: (content: string) => string;
};
/**
 * 日志打印接口.
 *
 * @export
 * @interface IDriver
 */
export interface IDriver {
    /**
     * 打印日志.
     *
     * @param {Level} level 日志级别
     * @param {string} moduleName 模块名
     * @param {Array} params 其他参数
     *
     * @memberof IDriver
     * @instance
     */
    log(level: Level, moduleName: string, ...params: any[]): void;
}
export default class Driver implements IDriver {
    readonly noColor: boolean;
    readonly noTime: boolean;
    readonly noModule: boolean;
    readonly noLevel: boolean;
    readonly cstyles_: Styles;
    constructor(conf?: KonphGlobal<ChivyConfig>);
    log(level: Level, moduleName: string, ...params: any[]): void;
    colorfully(level: Level, moduleName: string, ...params: any[]): void;
    monochromatically(level: Level, moduleName: string, ...params: any[]): void;
}
export {};
