/**
 * 路径封装类.
 *
 * @author Y3G
 */
/**
 * 路径封装类.
 *
 * 路径是指形如`a/b/c/d`的字符串, 其中`/`隔开的部分叫做分段, 分段可以为字符串、通配符`*`, 或者多分段通配符`**`
 * 注意, 在一个分段内, 不支持通配符和和其他字符混用.
 *
 * 相当于简陋版的minimatch(https://github.com/isaacs/minimatch).
 *
 * 可以通过赋值Logger.injector.Path替换.
 *
 * @export
 * @class Path
 */
export default class Path {
    sections_: Array<string>;
    str: string;
    /**
     * 路径分段列表
     *
     * @readonly
     *
     * @memberof Path
     */
    get sections(): string[];
    /**
     * Creates an instance of Path.
     *
     * @param {string|Path} str 路径字符串或其他路径对象, 不可为空字符串
     *
     * @memberof Path
     * @private
     */
    constructor(str: string);
    /**
     * 转化为字符串
     *
     * @returns {string} 转化结果
     *
     * @memberof Path
     * @instance
     */
    toString(): string;
    /**
     * 是否相等
     *
     * @param {string | Path} other 路径字符串或其他路径对象
     * @returns {boolean} 相等返回true, 否则返回false
     *
     * @memberof Path
     * @instance
     */
    equal(other: string | Path): boolean;
    /**
     * 是否匹配
     *
     * `a/#/b`可以匹配`a/foobar/b`, `a/##/b`可以匹配`a/foobar/b`、`a/foo/bar/b`以及`a/b`, `##`可以匹配任意路径(#号实际为*号)
     *
     * @param {string | Path} other 路径字符串或其他路径对象, 不可包含通配符
     * @returns {boolean} 匹配返回true, 否则返回false
     *
     * @memberof Path
     * @instance
     */
    match(other: string | Path): boolean;
}
